@@ -46,7 +46,7 @@ class Util:
 
     @staticmethod
     def _date_formats(
-        unix_timestamp: float, locale: str = "en", time_zone: str = "UTC"
+        unix_timestamp: float, locale: str = "en", time_zone: str = "UTC", custom_format: str = "%d. %B %Y"
     ) -> Dict[str, Any]:
         """
         Calculate different date formats / types.
@@ -55,10 +55,14 @@ class Util:
             unix_timestamp (float): A timestamp in seconds since 1970.
             locale (str): Locale code of language to use. Defaults to 'en'.
             time_zone (str): Timezone database name (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
+            custom_format (str): strftime format specifier for the 'custom' type
 
         Returns:
             dict: Different date formats.
         """
+        assert time_zone is not None
+        assert locale is not None
+        
         utc_revision_date = datetime.utcfromtimestamp(int(unix_timestamp))
         loc_revision_date = utc_revision_date.replace(
             tzinfo=get_timezone("UTC")
@@ -74,8 +78,8 @@ class Util:
             ),
             "iso_date": loc_revision_date.strftime("%Y-%m-%d"),
             "iso_datetime": loc_revision_date.strftime("%Y-%m-%d %H:%M:%S"),
-            "timeago": '<span class="timeago" datetime="%s" locale="%s"></span>'
-            % (loc_revision_date.isoformat(), locale),
+            "timeago": '<span class="timeago" datetime="%s" locale="%s"></span>' % (loc_revision_date.isoformat(), locale),
+            "custom": loc_revision_date.strftime(custom_format),
         }
 
     def get_git_commit_timestamp(
@@ -108,7 +112,7 @@ class Util:
             if is_first_commit:
                 # diff_filter="A" will select the commit that created the file
                 commit_timestamp = git.log(
-                    realpath, date="short", format="%at", diff_filter="A"
+                    realpath, date="unix", format="%at", diff_filter="A"
                 )
                 # A file can be created multiple times, through a file renamed. 
                 # Commits are ordered with most recent commit first
@@ -118,7 +122,7 @@ class Util:
             else:
                 # Latest commit touching a specific file
                 commit_timestamp = git.log(
-                    realpath, date="short", format="%at", n=1
+                    realpath, date="unix", format="%at", n=1
                 )
         except (InvalidGitRepositoryError, NoSuchPathError) as err:
             if self.config.get('fallback_to_build_date'):
@@ -175,7 +179,8 @@ class Util:
     def get_date_formats_for_timestamp(
         self,
         commit_timestamp: int,
-        add_spans: bool = True
+        locale: str,
+        add_spans: bool = True,
     ) -> Dict[str, str]:
         """
         Determine localized date variants for a given timestamp.
@@ -183,15 +188,16 @@ class Util:
         Args:
             commit_timestamp (int): most recent commit date in unix timestamp.
             locale (str, optional): Locale code of language to use. Defaults to 'en'.
-            time_zone (str): Timezone database name (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
+            add_spans: Wraps output in <span> elements with unique classes for easy CSS formatting
 
         Returns:
             dict: Localized date variants.
         """
         date_formats = self._date_formats(
             unix_timestamp=commit_timestamp, 
-            time_zone=self.config.get("time_zone"),
-            locale=self.config.get("locale")
+            time_zone=self.config.get("timezone"),
+            locale=locale,
+            custom_format=self.config.get('custom_format')
         )
         if add_spans:
             date_formats = self.add_spans(date_formats)
